// sample usage of if tag:
// <%@ taglib uri="/empTaglib" prefix="emp" %>
// ...
// <emp:setvar name="variable" value="123" />

package de.emprise.taglib;

// import needed for interface "Tag"
import javax.servlet.jsp.tagext.*;
// import needed for class PageContext, JspException, ...
import javax.servlet.jsp.*;

public class SetScriptVarTag implements Tag {

  // Class version string
  public static final String CLASS_VERSION = "SetScriptVarTag.java,v 1.0, 2001-07-19, Michael Maretzke";

  private PageContext _pagecontext;
  private Tag _parent;
  
  // Members for attributes connected to tag
  private String _name;
  private String _value;
  private String _type;
  
  // 
  // Attribute getter / setter 
  //
  
  // Attribute getter / setter for "name"
  public void setName(String name) {
    _name = name;
  }
  public String getName() {
    return _name;
  }
  
  // Attribute getter / setter for "value"
  public void setValue(String value) {
    _value = value;
  }
  public String getValue() {
    return _value;
  }
  
  // Attribute getter / setter for "type"
  public void setType(String type) {
    _type = type;
  }
  public String getType() {
    return _type;
  }

  //
  // Tag interface methods
  //
  
  // Set the current page context. Called by the page implementation prior to doStartTag(). 
  // This value is *not* reset by doEndTag() and must be explicitly reset by a page implementation
  public void setPageContext (PageContext pc) {
    _pagecontext = pc;
  }

  // Set the current nesting Tag of this Tag. Called by the page implementation prior to doStartTag(). 
  // This value is *not* reset by doEndTag() and must be explicitly reset by a page implementation. 
  // Code can assume that setPageContext has been called with the proper values before this point.
  public void setParent (Tag parent) {
    _parent = parent;
  }
  
  // Returns the parent tag of this instance.
  public Tag getParent () {
    return _parent;
  }

  // Called on a Tag handler to release state. The page compiler guarantees this method will be 
  // called on all tag handlers, but there may be multiple invocations on doStartTag and doEndTag 
  // in between.
  public void release () {
    _name = null;
    _value = null;
    _type = null;
      
    _pagecontext = null;
    _parent = null;
  }

  // Process the start tag for this instance.
  public int doStartTag () throws JspException {
    return SKIP_BODY;
  }

  // Process the end tag. This method will be called on all Tag objects.
  public int doEndTag () throws JspException {
    try {
      _pagecontext.setAttribute(_name, _value);
      // don't evaluate the body of the tag
      return EVAL_PAGE;  
    }
    catch (Exception e) {
      throw new JspException ("SetScriptVar Tag: " + e.getMessage());
    }    
  }  
}
