// sample usage of simple tag:
// <%@ taglib uri="/empTaglib" prefix="emp" %>
// ...
// <emp:simple />

package de.emprise.taglib;

// import needed for interface "Tag"
import javax.servlet.jsp.tagext.*;
// import needed for class PageContext, JspException, ...
import javax.servlet.jsp.*;

public class SimpleTag implements Tag {

  // Class version string
  public static final String CLASS_VERSION = "SimpleTag.java,v 1.0, 2001-07-19, Michael Maretzke";

  private PageContext _pagecontext;
  private Tag _parent;

  //
  // Tag interface methods
  //
  
  // Set the current page context. Called by the page implementation prior to doStartTag(). 
  // This value is *not* reset by doEndTag() and must be explicitly reset by a page implementation
  public void setPageContext (PageContext pc) {
    _pagecontext = pc;
  }

  // Set the current nesting Tag of this Tag. Called by the page implementation prior to doStartTag(). 
  // This value is *not* reset by doEndTag() and must be explicitly reset by a page implementation. 
  // Code can assume that setPageContext has been called with the proper values before this point.
  public void setParent (Tag parent) {
    _parent = parent;
  }
  
  // Returns the parent tag of this instance.
  public Tag getParent () {
    return _parent;
  }

  // Called on a Tag handler to release state. The page compiler guarantees this method will be 
  // called on all tag handlers, but there may be multiple invocations on doStartTag and doEndTag 
  // in between.
  public void release () {
    _pagecontext = null;
    _parent = null;
  }

  // Process the start tag for this instance.
  public int doStartTag () throws JspException {
    try {
      _pagecontext.getOut().print("This was Michael's \"Simple\" Tag.");
      // don't evaluate the body of the tag
      return SKIP_BODY;
    }
    catch (Exception e) {
      throw new JspException ("Simple Tag: " + e.getMessage());
    }
  }

  // Process the end tag. This method will be called on all Tag objects.
  public int doEndTag () throws JspException {
    return EVAL_PAGE;
  }  
}
